@@ -6,7 +6,7 @@ from typing import Dict, Union
 import requests
 
 # IMPORTATION INTERNAL
-import degiro_connector.core.constants.urls as urls
+from degiro_connector.core.constants import urls
 from degiro_connector.core.abstracts.abstract_action import AbstractAction
 
 
@@ -34,7 +34,7 @@ class ActionGetClientDetails(AbstractAction):
         response_raw = None
 
         try:
-            response_raw = session.send(prepped, verify=False)
+            response_raw = session.send(prepped)
             response_raw.raise_for_status()
             response_dict = response_raw.json()
         except requests.HTTPError as e:
