@@ -7,7 +7,7 @@ import requests
 from google.protobuf import json_format
 
 # IMPORTATION INTERNAL
-import degiro_connector.core.constants.urls as urls
+from degiro_connector.core.constants import urls
 from degiro_connector.core.abstracts.abstract_action import AbstractAction
 from degiro_connector.trading.models.trading_pb2 import (
     Credentials,
@@ -119,7 +119,7 @@ class ActionUpdateOrder(AbstractAction):
         response_raw = None
 
         try:
-            response_raw = session.send(prepped, verify=False)
+            response_raw = session.send(prepped)
             response_raw.raise_for_status()
         except requests.HTTPError as e:
             status_code = getattr(response_raw, "status_code", "No status_code found.")
